<?php
	/***************
	 * more_extended.php
	 * This file was generated to demonstrate only 1 way
	 * of form processing and handling errors.  The disadvantage
	 * of doing things this way, is that the code we use is
	 * all in one page.  A good exercise is to recode this page
	 * making it more extensiable and reusable. (HINT: classes
	 * and common functions).
	 * 
	 * Jaime Ruiz 		initial		Feb 8, 2015
	 */

	//Define some variables used throughout the page
	$form_data = array();
	$errors = array();
	$states = array();
	
	//1. let's process the form first because we are going to redirect.
	// Check to see if hidden submitted was passed
	if(isset($_POST["submitted"])){
		//I am moving the POST data to the form data array so I can use
		//it later
		foreach ($_POST as $key=>$value){
			$form_data[$key] = $value;
		}
		//Now let's check for required fields
		if($form_data["first_name"] == ""){
			$errors["first_name"] = "First Name is required";
		}
		//Another way to check empty string
		if(empty($form_data["email"])){
			$errors["email"] = "Email address is required.";
		}elseif(!filter_var($form_data["email"],
				$filter=FILTER_VALIDATE_EMAIL)){
			//Use built-in validator to validate email
			//http://php.net/manual/en/filter.filters.validate.php
			$errors["email"] = "Please enter a valid email.";
		}
	
		if($form_data["state"] == -1){
			$errors["state"] = "Please select your state.";
		}
		//If done then redirect
		if(empty($errors)){
			header("Location: thankyou.php");
			return;
		}
	} //End form if
	
	//Include example header
	$exNumText = "More Extended";
	include 'ct310phpexHeader.php';
	
	//Let's load the states
	//State table was aquired from statetable.com. It contains
	//a lot of information and we may use it later. If this wasn't
	//for a class, my file would only contain state name and abbriviation
	
	//2. This loads the file contents into an array using file and removes
	//	 the newline character at the end
	$state_file_array = file("state_table.csv", $flag=FILE_IGNORE_NEW_LINES);
	//The first line is going to be the keys
	//so we are going to "split" the line into an array using ","
	$state_file_keys = preg_split("/,/", $state_file_array[0]);
	//let's output this as a comment just so you can see what happened.
	echo "<!-- ";
	print_r($state_file_keys);
	echo "-->\n";
	//Since we read in line[0] let's remove it from the array
	unset($state_file_array[0]);
	//Now let's build the state array
	foreach($state_file_array as $line){
		//The best way to split a csv line because entries
		//may have a comma. For example if I use expode(",", $line)
		//and a value has a comma then it will split that value. Look
		//at line 83 of the states file and you will know what i mean.
		$values = str_getcsv($line);
		//Use for loop to get key from key array
		$new_state = array();
		for($i=0; $i < count($values); $i++){
			//Set key and value for state
			$new_state[$state_file_keys[$i]] = $values[$i];
		}
		//Add state to states array. This pushes the state to the 
		//end of an array. this is better than array_push() since we
		//are only adding one item
		$states[] = $new_state;
	}
	
	
	//Adding a function to check if input has error
	//and if so return class
	function checkForError($field_name){
		//Need to tell php we are using global errors
		global $errors;
		//Short hand if statement
		return (isset($errors[$field_name]))? " error": ""; 
	}
	//Use this because form_data doesn't always have the value set
	function getValue($field_name){
		global $form_data;
		return (isset($form_data[$field_name]))? $form_data[$field_name] : "";
	}
	
?>
<!-- -5pts for putting styles in the body and not head tag.
	However, I did it this way to reuse the example header -->
<style type="text/css">
	@import 'more_extended.css';	
</style>
<!-- Using this because instead of header tag because
the doctype is not html5 but xhtml -->
<div class="header">
<?php echo "   <h2> CT 310 PHP Example $exNumText </h2>\n"; ?>
</div>

<div class="page-wrap">
	<h1>Newsletter Signup</h1>
	<?php 
		if(count($errors) > 0){ ?>
		<h3 class="error">Please fix the following errors.</h3>
			<ul class="error">
				<?php 	
					//This for each will load the key of the
					//array into the $field variable and the value
					//into the $error variable
					foreach($errors as $field => $error){
						echo "<li>$error</li>";
					}
				?> 
			</ul>
	<?php		
		} //End if count($errors);
	?>
	<form id="newsletter_form" action="more_extended.php" method="post">
		<div class="form_row">
			<label for="first_name" 
			class="required<?php echo checkForError("first_name")?>">First Name</label>
			<input type="text" name="first_name" id="first_name"
				class="required<?php echo checkForError("first_name")?>" 
				value="<?php echo getValue("first_name");?>" placeholder="First Name" />
		</div>
		<div class="form_row">
			<label for="email" 
				class="required<?php echo checkForError("email")?>">Email</label>
			<input type="text" name="email" id="email"
				value="<?php getValue("email");?>"  class="required<?php echo checkForError("email")?>"/>
		</div>
		<div class="form_row">
			<label for="state" class="required<?php echo checkForError("state")?>">State</label>
			<select name="state" id="state" class="required<?php echo checkForError("state")?>">
				<option value="-1">Select One</option>
				<?php 
					foreach($states as $state){
						echo '<option value="'. $state['abbreviation'] . '"';
						echo (isset($form_data['state']) && $form_data['state'] == $state['abbreviation'])? "selected":'';
						echo '>'. $state['name'] . '</option>';
					}
				?>
			</select>
		</div>
		<div class="form_row">
		
			<label for="bio">Bio (optional)</label>
			<textarea name="bio" id="bio" cols="20" rows="4"><?php echo getValue("bio");?></textarea>
		</div>
		<div class="form_row">
			<input type="hidden" name="submitted" value="1" />
			<input type="submit" value="Submit Me" />
		</div>
	</form>
	<hr />
</div>

<?php include 'ct310phpexFooter.html'; ?>
